﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using DAL;
using Domain;
using Interfaces;

namespace Web.Controllers
{
    public class SubjectsController : Controller
    {
        //private AppDbContext db = new AppDbContext();
        private ISubjectRepository _subjectRepository;

        public SubjectsController(ISubjectRepository subjectRepository)
        {
            _subjectRepository = subjectRepository;
        }

        // GET: Subjects
        public ActionResult Index()
        {
            return View(model: _subjectRepository.All);
        }

        // GET: Subjects/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(statusCode: HttpStatusCode.BadRequest);
            }
            Subject subject = _subjectRepository.Find(id: id.Value);
            if (subject == null)
            {
                return HttpNotFound();
            }
            return View(model: subject);
        }

        // GET: Subjects/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: Subjects/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see https://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "SubjectId,SubjectName")] Subject subject)
        {
            if (ModelState.IsValid)
            {
                _subjectRepository.Add(entity: subject);
                _subjectRepository.SaveChanges();
                return RedirectToAction(actionName: "Index");
            }

            return View(model: subject);
        }

        // GET: Subjects/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(statusCode: HttpStatusCode.BadRequest);
            }
            Subject subject = _subjectRepository.Find(id: id.Value );
            if (subject == null)
            {
                return HttpNotFound();
            }
            return View(model: subject);
        }

        // POST: Subjects/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see https://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "SubjectId,SubjectName")] Subject subject)
        {
            if (ModelState.IsValid)
            {
                _subjectRepository.Update(entity: subject);
                _subjectRepository.SaveChanges();
                return RedirectToAction(actionName: "Index");
            }
            return View(model: subject);
        }

        // GET: Subjects/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(statusCode: HttpStatusCode.BadRequest);
            }
            Subject subject = _subjectRepository.Find(id: id.Value);
            if (subject == null)
            {
                return HttpNotFound();
            }
            return View(model: subject);
        }

        // POST: Subjects/Delete/5
        [HttpPost, ActionName(name: "Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            _subjectRepository.Remove(id: id);
            _subjectRepository.SaveChanges();
            return RedirectToAction(actionName: "Index");
        }

    }
}
